@@ -37,11 +37,11 @@ class clientlib(object):
         if self.ws_interface.connected():
             self.ws_interface.close()
 
-    def get_dataplane(self, stream_name):
-        return dataplane(self.host, self.port, stream_name)
+    def get_dataplane(self, stream_name, callback=None):
+        return dataplane(self.host, self.port, stream_name, callback)
 
-    def get_logstreamer(self):
-        return logstreamer(self.host, self.port)
+    def get_logstreamer(self, callback=None):
+        return logstreamer(self.host, self.port, callback)
 
 
 
